..
   Generated: Thu Mar 23 15:03:55 2017

   @author : Eric Lapouyade

======
recode
======

.. automodule:: textops.ops.recode
.. currentmodule:: textops

list_to_multilinestring
-----------------------
   .. autoclass:: list_to_multilinestring(in_place=False, tag='-------------------------< Multiline string as list >-------------------------')

multilinestring_to_list
-----------------------
   .. autoclass:: multilinestring_to_list(in_place=False)
